pub struct MatchedFile {
pub path: PathBuf,
pub bytes: u64,
pub content: String,
}Expand description
One file the resolver matched against an agent’s pattern set.
path is the file’s path relative to the repo root, normalized to use
forward slashes regardless of the host platform (downstream agents resolve
relative paths against the repo, and absolute paths leak local filesystem
layout).
Fields
path: PathBufbytes: u64content: StringTrait Implementations
Sourceimpl Clone for MatchedFile
impl Clone for MatchedFile
Sourcefn clone(&self) -> MatchedFile
fn clone(&self) -> MatchedFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchedFile
impl Debug for MatchedFile